Welcome,

This plugin is used to retrieve the granular website visitor activity data, that is automatically
captured and tagged by Convizit, and use it in your Python code.

## To install, use:
`pip install convizit`

## Documentation:
- [Read here on how to use the plugin functions](https://github.com/Convizit/API/wiki/03-Visitor-Activity-Data-Functions)
- [Click here to read about Convizit API](https://github.com/Convizit/API/wiki/01-Getting-Started)
- [PyPI link](https://pypi.org/project/convizit/)

## Quick demonstration:
Let's see what can be done with Convizit Python-plugin:

First, let's import the Convizit class from the package.


```python
from convizit_pkg import Convizit
```

Now we create a Convizit instance, to do it login, password and site token are needed.
I will insert our test website details to continue (I've initialized the login, password and siteToken variables earlier).


```python
data_supplier = Convizit(login, password, siteToken)
```

Now let's use our Convizit instance to get the page views for the following time interval:


```python
page_visits = data_supplier.getVisits(fromTime='2018-06-20 16:10:07', toTime='2019-01-20 16:10:07')
page_visits[0]
```




    {'identifier': '8818',
     'localTimestamp': '2018-06-09T18:58:52.000Z',
     'globalTimestamp': '2018-06-09T15:58:52.000Z',
     'pageURL': 'https://con-shop-store.myshopify.com/',
     'pageTitle': 'Store – Con Shop Store',
     'referrer': None,
     'campaign': None,
     'userAgent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/66.0.3359.181 Safari/537.36',
     'device': 'Desktop',
     'platform': 'Windows'}



We've got back a list of dictionaries.
As can be seen from the output, for every page visit we receive the time of the vizit, page url, page title and more...
Let's use Pandas DataFrame to examine our data:


```python
import pandas as pd
df = pd.DataFrame.from_records(page_visits)
df.head(3)
```

<table border="1" class="dataframe">
  <thead>
    <tr style="text-align: right;">
      <th></th>
      <th>campaign</th>
      <th>device</th>
      <th>globalTimestamp</th>
      <th>identifier</th>
      <th>localTimestamp</th>
      <th>pageTitle</th>
      <th>pageURL</th>
      <th>platform</th>
      <th>referrer</th>
      <th>userAgent</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <th>0</th>
      <td>None</td>
      <td>Desktop</td>
      <td>2018-06-09T15:58:52.000Z</td>
      <td>8818</td>
      <td>2018-06-09T18:58:52.000Z</td>
      <td>Store – Con Shop Store</td>
      <td>https://con-shop-store.myshopify.com/</td>
      <td>Windows</td>
      <td>None</td>
      <td>Mozilla/5.0 (Windows NT 10.0; Win64; x64) Appl...</td>
    </tr>
    <tr>
      <th>1</th>
      <td>None</td>
      <td>Desktop</td>
      <td>2018-06-09T16:00:48.000Z</td>
      <td>92510</td>
      <td>2018-06-09T19:00:48.000Z</td>
      <td>Store – Con Shop Store</td>
      <td>https://con-shop-store.myshopify.com/</td>
      <td>Windows</td>
      <td>None</td>
      <td>Mozilla/5.0 (Windows NT 10.0; Win64; x64) Appl...</td>
    </tr>
    <tr>
      <th>2</th>
      <td>None</td>
      <td>Desktop</td>
      <td>2018-06-09T16:00:48.000Z</td>
      <td>92510</td>
      <td>2018-06-09T19:00:48.000Z</td>
      <td>Store – Con Shop Store</td>
      <td>https://con-shop-store.myshopify.com/</td>
      <td>Windows</td>
      <td>None</td>
      <td>Mozilla/5.0 (Windows NT 10.0; Win64; x64) Appl...</td>
    </tr>
  </tbody>
</table>
</div>



Now let's see how many visitors every page in our website got during this time interval:


```python
df.groupby(['pageTitle']).size().reset_index(name='num of visits').sort_values('num of visits', ascending=False)
```




<div>
<table border="1" class="dataframe">
  <thead>
    <tr style="text-align: right;">
      <th></th>
      <th>pageTitle</th>
      <th>num of visits</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <th>21</th>
      <td>Store – Con Shop Store</td>
      <td>69</td>
    </tr>
    <tr>
      <th>23</th>
      <td>Your Shopping Cart – Con Shop Store</td>
      <td>25</td>
    </tr>
    <tr>
      <th>18</th>
      <td>Products – Con Shop Store</td>
      <td>18</td>
    </tr>
    <tr>
      <th>22</th>
      <td>Womens Jackets – Con Shop Store</td>
      <td>13</td>
    </tr>
    <tr>
      <th>17</th>
      <td>Mens Jackets – Con Shop Store</td>
      <td>13</td>
    </tr>
    <tr>
      <th>16</th>
      <td>Jewlery – Con Shop Store</td>
      <td>10</td>
    </tr>
    <tr>
      <th>2</th>
      <td>A-Line Jacket – Con Shop Store</td>
      <td>7</td>
    </tr>
    <tr>
      <th>9</th>
      <td>Alverstone Jacket in Midnight – Con Shop Store</td>
      <td>7</td>
    </tr>
    <tr>
      <th>11</th>
      <td>Big Army Jacket in Olive – Con Shop Store</td>
      <td>6</td>
    </tr>
    <tr>
      <th>19</th>
      <td>Products – Page 2 – Con Shop Store</td>
      <td>6</td>
    </tr>
    <tr>
      <th>0</th>
      <td>3/4 Sleeve Kimono Dress – Con Shop Store</td>
      <td>6</td>
    </tr>
    <tr>
      <th>12</th>
      <td>Bracelet 65 in Black – Con Shop Store</td>
      <td>6</td>
    </tr>
    <tr>
      <th>15</th>
      <td>Darell Jacket – Con Shop Store</td>
      <td>5</td>
    </tr>
    <tr>
      <th>10</th>
      <td>Anatole Ring – Con Shop Store</td>
      <td>4</td>
    </tr>
    <tr>
      <th>13</th>
      <td>Cila Jumper in Mud – Con Shop Store</td>
      <td>4</td>
    </tr>
    <tr>
      <th>8</th>
      <td>Ally Ring – Con Shop Store</td>
      <td>4</td>
    </tr>
    <tr>
      <th>1</th>
      <td>5 Pocket Jean – Con Shop Store</td>
      <td>3</td>
    </tr>
    <tr>
      <th>5</th>
      <td>ACB Top – Con Shop Store</td>
      <td>3</td>
    </tr>
    <tr>
      <th>14</th>
      <td>Cotton Jacket in Navy – Con Shop Store</td>
      <td>2</td>
    </tr>
    <tr>
      <th>6</th>
      <td>Adania Pant – Con Shop Store</td>
      <td>2</td>
    </tr>
    <tr>
      <th>7</th>
      <td>Alex Twill Pant in Mariner – Con Shop Store</td>
      <td>1</td>
    </tr>
    <tr>
      <th>20</th>
      <td>Products – Page 3 – Con Shop Store</td>
      <td>1</td>
    </tr>
    <tr>
      <th>4</th>
      <td>A-Line Pocket Shift in Black – Con Shop Store</td>
      <td>1</td>
    </tr>
    <tr>
      <th>3</th>
      <td>A-Line Mini Dress in Blue – Con Shop Store</td>
      <td>1</td>
    </tr>
  </tbody>
</table>
</div>



We got the complete list of pages in our website and their number of visitors during this time interval.
We can see that the most visited page is 'Store - Con Shop Store' with 69 vizitors, which is the homepage of this website.


