import requests
import json
import os
import hmac
from hashlib import sha1


# The following block loads the configurations (such as url) from the config.json file
# ----------------------------------------------------------------------------------------------------------------------

__CURRENT_DIRECTORY = os.path.abspath(os.path.dirname(__file__))
__CONFIG_FILE_PATH = os.path.join(__CURRENT_DIRECTORY, 'config.json')

AUTHORIZE_URL = '/general/Authorize'


with open(__CONFIG_FILE_PATH, 'r') as cfg:
    URL = json.load(cfg)['cfg']['url']

# ----------------------------------------------------------------------------------------------------------------------


class Convizit:
    """
    The class that is used to connect to Convizit DataBase.
    """
    def __init__(self, siteToken, apiKey, apiSecret):
        self.siteToken = siteToken
        self.apiKey = apiKey
        self.apiSecret = apiSecret
        self.__authorize()

    def __executeRequest(self, method, url, data={}, params={}, headers={}):
        requestUrl = URL + url
        if hasattr(self, 'accessToken'):
            headers['X-Auth-Token'] = self.accessToken
        request = requests.request(
            method, requestUrl, data=data, params=params, headers=headers)
        return request.json()

    def __authorize(self):
        data = {"apiKey": self.apiKey, "siteToken": self.siteToken}
        hash_input = AUTHORIZE_URL + json.dumps(data).replace(' ', '')
        hashed = hmac.new(self.apiSecret.encode('utf-8'), hash_input.encode('utf-8'), sha1)
        hash_result = hashed.hexdigest()
        headers = {'Sign': hash_result}
        response = self.__executeRequest('POST', AUTHORIZE_URL,
                                         data=data,
                                         headers=headers)
        self.accessToken = response['token']

    def getEvents(self, **kwargs):
        response = self.__executeRequest('GET', '/activity/GetEvents', params=kwargs)
        return response

    def getSessions(self, **kwargs):
        response = self.__executeRequest('GET', '/activity/GetSessions', params=kwargs)
        return response

    def getVisits(self, **kwargs):
        response = self.__executeRequest('GET', '/activity/GetPageviews', params=kwargs)
        return response

    def getElements(self, **kwargs):
        response = self.__executeRequest('GET', '/activity/GetElements', params=kwargs)
        return response

    def getPages(self, **kwargs):
        response = self.__executeRequest('GET', '/activity/GetPages', params=kwargs)
        return response

